# Hits:
A list of IP addresses that accessed the selected link.


## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Accessed:
Date and time at which the link was accessed.
### IP Address:
The IP address that accessed the link.
### Meta Data:
The meta data that was provided when the link was accessed. Comprised of things like operating system and browser name.

## Filters:
### Shareable Link:
Display hits for a specific link. Will default to the current link displayed.

## Search Field:
Typing in the search field allows to filter by IP address.
